<?php

namespace Drupal\skipto\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure settings for this site.
 */
class SkiptoColorThemes extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'skipto_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['skipto.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('skipto.settings');

    $form['override'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Override color themes'),
      '#default_value' => $config->get('override'),
      '#description' => $this->t('Override the Color Theme values'),
    ];

    $form['unchecked'] = [
      '#type' => 'container',
      '#states' => [
        'visible' => [
          ':input[name="override"]' => ['checked' => FALSE],
        ],
      ],
    ];

    $form['unchecked']['colorTheme'] = [
      '#type' => 'select',
      '#title' => $this->t('Color Theme Options'),
      '#description' => $this->t('A predefined color scheme for skipTo'),
      '#options' => [
        'aria' => $this->t('aria'),
        'illinois' => $this->t('illinois'),
        'uic' => $this->t('uic'),
        'uillinois' => $this->t('uillinois'),
        'uis' => $this->t('uis'),
        'openweba11y' => $this->t('openweba11y'),
      ],
      '#default_value' => $config->get('unchecked.colorTheme'),
    ];

    $form['checked'] = [
      '#type' => 'container',
      '#states' => [
        'visible' => [
          ':input[name="override"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $form['checked']['buttonTextColor'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Button Text Color'),
      '#description' => $this->t('Color of text for “Skip To Content” button.'),
      '#required' => TRUE,
      '#default_value' => $config->get('checked.buttonTextColor'),
    ];

    $form['checked']['buttonBackgroundColor'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Button Background Color'),
      '#description' => $this->t('Background color of text for “Skip To Content” button.'),
      '#required' => TRUE,
      '#default_value' => $config->get('checked.buttonBackgroundColor'),
    ];

    $form['checked']['focusBorderColor'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Focus Border Color'),
      '#description' => $this->t('Border color for items with keyboard focus.'),
      '#required' => TRUE,
      '#default_value' => $config->get('checked.focusBorderColor'),
    ];

    $form['checked']['menuTextColor'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Menu Text Color'),
      '#description' => $this->t('Menu text color'),
      '#required' => TRUE,
      '#default_value' => $config->get('checked.menuTextColor'),
    ];

    $form['checked']['menuBackgroundColor'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Menu Background Color'),
      '#description' => $this->t('Menu background color.'),
      '#required' => TRUE,
      '#default_value' => $config->get('checked.menuBackgroundColor'),
    ];

    $form['checked']['menuitemFocusTextColor'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Focus Color Menu Item'),
      '#description' => $this->t('Menuitem text color when a menuitem has focus.'),
      '#required' => TRUE,
      '#default_value' => $config->get('checked.menuitemFocusTextColor'),
    ];

    $form['checked']['menuitemFocusBackgroundColor'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Focus background color'),
      '#description' => $this->t('Menuitem text background when a menuitem has focus.'),
      '#required' => TRUE,
      '#default_value' => $config->get('checked.menuitemFocusBackgroundColor'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $config = $this->configFactory->getEditable('skipto.settings');
    $config
      ->set('override', $form_state->getValue('override'))
      ->set('unchecked.colorTheme', $form_state->getValue('colorTheme'))
      ->set('checked.buttonTextColor', $form_state->getValue('buttonTextColor'))
      ->set('checked.buttonBackgroundColor', $form_state->getValue('buttonBackgroundColor'))
      ->set('checked.focusBorderColor', $form_state->getValue('focusBorderColor'))
      ->set('checked.menuTextColor', $form_state->getValue('menuTextColor'))
      ->set('checked.menuBackgroundColor', $form_state->getValue('menuBackgroundColor'))
      ->set('checked.menuitemFocusTextColor', $form_state->getValue('menuitemFocusTextColor'))
      ->set('checked.menuitemFocusBackgroundColor', $form_state->getValue('menuitemFocusBackgroundColor'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
