<?php

namespace Drupal\skipto\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure settings for this site.
 */
class SkiptoLabels extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'skipto_form_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['skipto.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('skipto.settings');

    $form['button'] = [
      '#type' => 'details',
      '#title' => $this->t('Button Labels'),
      '#description' => $this->t('The labels and messages can be localized for specific languages or reflect user preferences.'),
      '#open' => TRUE,
      '#tree' => TRUE,
    ];

    $form['button']['buttonLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Button Label'),
      '#description' => $this->t('Color of text for “Skip To Content” button.'),
      '#required' => TRUE,
      '#default_value' => $config->get('button.buttonLabel'),
    ];

    $form['button']['smallButtonLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Small Button Label'),
      '#description' => $this->t('Change the text label of the menu button in small screen sizes.'),
      '#required' => TRUE,
      '#default_value' => $config->get('button.smallButtonLabel'),
    ];

    $form['button']['altLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Alt Label'),
      '#description' => $this->t('Label for modifier key for Windows and Unix/Linux operating systems'),
      '#required' => TRUE,
      '#default_value' => $config->get('button.altLabel'),
    ];

    $form['button']['optionLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Option Label'),
      '#description' => $this->t('Label for modifier key for macOS operating systems'),
      '#required' => TRUE,
      '#default_value' => $config->get('button.optionLabel'),
    ];

    $form['button']['shortcutLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Button Label'),
      '#description' => $this->t('Color of text for “Skip To Content” button.'),
      '#required' => TRUE,
      '#default_value' => $config->get('button.shortcutLabel'),
    ];

    $form['menu'] = [
      '#type' => 'details',
      '#title' => $this->t('Menu Labels'),
      '#description' => $this->t('The labels and messages can be localized for specific languages or reflect user preferences.'),
      '#open' => TRUE,
      '#tree' => TRUE,
    ];

    $form['menu']['menuLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Menu Label'),
      '#description' => $this->t('Change the label for the menu.'),
      '#required' => TRUE,
      '#default_value' => $config->get('menu.menuLabel'),
    ];

    $form['menu']['landmarkGroupLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Landmark Group Label'),
      '#description' => $this->t('Menu group label for landmarks.'),
      '#required' => TRUE,
      '#default_value' => $config->get('menu.landmarkGroupLabel'),
    ];

    $form['menu']['headingGroupLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Menu Label'),
      '#description' => $this->t('Menu group label for headings.'),
      '#required' => TRUE,
      '#default_value' => $config->get('menu.headingGroupLabel'),
    ];

    $form['menu']['headingLevelLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Heading Level Label'),
      '#description' => $this->t('Used for aria-label to improve labeling of heading menu items for screen reader users.'),
      '#required' => TRUE,
      '#default_value' => $config->get('menu.headingLevelLabel'),
    ];

    $form['landmark'] = [
      '#type' => 'details',
      '#title' => $this->t('Landmark Labels'),
      '#description' => $this->t('The names of landmark region names can be localized for specific languages or reflect user preferences.'),
      '#open' => TRUE,
      '#tree' => TRUE,
    ];

    $form['landmark']['mainLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Heading Level Label'),
      '#description' => $this->t('Used for aria-label to improve labeling of heading menu items for screen reader users.'),
      '#required' => TRUE,
      '#default_value' => $config->get('landmark.mainLabel'),
    ];

    $form['landmark']['searchLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Heading Level Label'),
      '#description' => $this->t('Used for aria-label to improve labeling of heading menu items for screen reader users.'),
      '#required' => TRUE,
      '#default_value' => $config->get('landmark.searchLabel'),
    ];

    $form['landmark']['navLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Heading Level Label'),
      '#description' => $this->t('Used for aria-label to improve labeling of heading menu items for screen reader users.'),
      '#required' => TRUE,
      '#default_value' => $config->get('landmark.navLabel'),
    ];

    $form['landmark']['asideLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Heading Level Label'),
      '#description' => $this->t('Used for aria-label to improve labeling of heading menu items for screen reader users.'),
      '#required' => TRUE,
      '#default_value' => $config->get('landmark.asideLabel'),
    ];

    $form['landmark']['footerLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Heading Level Label'),
      '#description' => $this->t('Used for aria-label to improve labeling of heading menu items for screen reader users.'),
      '#required' => TRUE,
      '#default_value' => $config->get('landmark.footerLabel'),
    ];

    $form['landmark']['headerLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Heading Level Label'),
      '#description' => $this->t('Used for aria-label to improve labeling of heading menu items for screen reader users.'),
      '#required' => TRUE,
      '#default_value' => $config->get('landmark.headerLabel'),
    ];

    $form['landmark']['formLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Heading Level Label'),
      '#description' => $this->t('Used for aria-label to improve labeling of heading menu items for screen reader users.'),
      '#required' => TRUE,
      '#default_value' => $config->get('landmark.formLabel'),
    ];

    $form['landmark']['msgNoLandmarksFound'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Heading Level Label'),
      '#description' => $this->t('Used for aria-label to improve labeling of heading menu items for screen reader users.'),
      '#required' => TRUE,
      '#default_value' => $config->get('landmark.msgNoLandmarksFound'),
    ];

    $form['landmark']['msgNoHeadingsFound'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Heading Level Label'),
      '#description' => $this->t('Used for aria-label to improve labeling of heading menu items for screen reader users.'),
      '#required' => TRUE,
      '#default_value' => $config->get('landmark.msgNoHeadingsFound'),
    ];

    $form['about'] = [
      '#type' => 'details',
      '#title' => $this->t('About'),
      '#description' => $this->t('The names of landmark region names can be localized for specific languages or reflect user preferences.'),
      '#open' => TRUE,
      '#tree' => TRUE,
    ];

    $form['about']['aboutInfoLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Heading Level Label'),
      '#description' => $this->t('Used for aria-label to improve labeling of heading menu items for screen reader users.'),
      '#required' => TRUE,
      '#default_value' => $config->get('about.aboutInfoLabel'),
    ];

    $form['about']['aboutDesc'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Heading Level Label'),
      '#description' => $this->t('Used for aria-label to improve labeling of heading menu items for screen reader users.'),
      '#maxlength' => 150,
      '#required' => TRUE,
      '#default_value' => $config->get('about.aboutDesc'),
    ];

    $form['about']['aboutVersion'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Heading Level Label'),
      '#description' => $this->t('Used for aria-label to improve labeling of heading menu items for screen reader users.'),
      '#required' => TRUE,
      '#default_value' => $config->get('about.aboutVersion'),
    ];

    $form['about']['aboutCopyright'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Heading Level Label'),
      '#description' => $this->t('Used for aria-label to improve labeling of heading menu items for screen reader users.'),
      '#required' => TRUE,
      '#default_value' => $config->get('about.aboutCopyright'),
    ];

    $form['about']['aboutHappy'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Heading Level Label'),
      '#description' => $this->t('Used for aria-label to improve labeling of heading menu items for screen reader users.'),
      '#required' => TRUE,
      '#default_value' => $config->get('about.aboutHappy'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $config = $this->config('skipto.settings');
    $config
      ->set('button.buttonLabel', $form_state->getValue([
        'button',
        'buttonLabel',
      ]))
      ->set('button.smallButtonLabel', $form_state->getValue([
        'button',
        'smallButtonLabel',
      ]))
      ->set('button.altLabel', $form_state->getValue([
        'button',
        'altLabel',
      ]))
      ->set('button.optionLabel', $form_state->getValue([
        'button',
        'optionLabel',
      ]))
      ->set('button.shortcutLabel', $form_state->getValue([
        'button',
        'shortcutLabel',
      ]))
      ->set('menu.menuLabel', $form_state->getValue([
        'menu',
        'menuLabel',
      ]))
      ->set('menu.landmarkGroupLabel', $form_state->getValue([
        'menu',
        'landmarkGroupLabel',
      ]))
      ->set('menu.headingGroupLabel', $form_state->getValue([
        'menu',
        'headingGroupLabel',
      ]))
      ->set('menu.headingLevelLabel', $form_state->getValue([
        'menu',
        'headingLevelLabel',
      ]))
      ->set('landmark.mainLabel', $form_state->getValue([
        'landmark',
        'mainLabel',
      ]))
      ->set('landmark.searchLabel', $form_state->getValue([
        'landmark',
        'searchLabel',
      ]))
      ->set('landmark.navLabel', $form_state->getValue([
        'landmark',
        'navLabel',
      ]))
      ->set('landmark.asideLabel', $form_state->getValue([
        'landmark',
        'asideLabel',
      ]))
      ->set('landmark.footerLabel', $form_state->getValue([
        'landmark',
        'footerLabel',
      ]))
      ->set('landmark.headerLabel', $form_state->getValue([
        'landmark',
        'headerLabel',
      ]))
      ->set('landmark.formLabel', $form_state->getValue([
        'landmark',
        'formLabel',
      ]))
      ->set('landmark.msgNoLandmarksFound', $form_state->getValue([
        'landmark',
        'msgNoLandmarksFound',
      ]))
      ->set('landmark.msgNoHeadingsFound', $form_state->getValue([
        'landmark',
        'msgNoHeadingsFound',
      ]))
      ->set('about.aboutInfoLabel', $form_state->getValue([
        'about',
        'aboutInfoLabel',
      ]))
      ->set('about.aboutDesc', $form_state->getValue([
        'about',
        'aboutDesc',
      ]))
      ->set('about.aboutVersion', $form_state->getValue([
        'about',
        'aboutVersion',
      ]))
      ->set('about.aboutCopyright', $form_state->getValue([
        'about',
        'aboutCopyright',
      ]))
      ->set('about.aboutHappy', $form_state->getValue([
        'about',
        'aboutHappy',
      ]))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
