<?php

namespace Drupal\skipto\Form;

use Drupal\Core\Config\ConfigInstallerInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class ResetValuesForm.
 */
class SkiptoRestore extends FormBase {

  /**
   * The config installer service.
   *
   * @var \Drupal\Core\Config\ConfigInstallerInterface
   */
  protected $configInstaller;

  /**
   * Constructs a new SkiptoRestore form.
   *
   * @param \Drupal\Core\Config\ConfigInstallerInterface $config_installer
   *   The config installer service.
   */
  public function __construct(ConfigInstallerInterface $config_installer) {
    $this->configInstaller = $config_installer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): SkiptoRestore {
    return new SkiptoRestore(
      $container->get('config.installer')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'reset_values_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['reset'] = [
      '#type' => 'submit',
      '#value' => $this->t('Restore defaults'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->configInstaller->installDefaultConfig('module', 'skipto');
    $this->messenger()->addStatus($this->t('Values have been reset to the default values.'));
    $form_state->setRedirect('skipto.restore');
  }

}
